@@ -2,7 +2,7 @@ package Date::Holidays::UK::EnglandAndWales;
 use strict;
 use warnings;
 
-our $VERSION = '0.02'; # Added tie
+our $VERSION = '0.03'; # Updated dates
 
 require Exporter;
 require Tie::Hash ;
@@ -37,7 +37,7 @@ the dates needed by my clients.
 As Msrs Clamp et al note in the L<POD for their module|Date::Holidays::UK/DESCRIPTION>,
 Naming modules is a tricky thing: I've named this C<EnglandAndWales> because
 the C<UK> module cannot include holidays for Northern Ireland and Scotland,
-and maintain its API.
+and maintain its API, since the dates vary across the UK for events of the same name.
 
 =head2 USE
 
@@ -66,7 +66,10 @@ be removed in a future version.
 our (%holidays, %_holidays);
 
 $_holidays{ 2005,  1,  3 } =
-$_holidays{ 2006,  1,  2 } = "Substitute Bank Holiday in lieu of 1 Jan";
+$_holidays{ 2006,  1,  2 } =
+$_holidays{ 2011,  1,  3 } =
+$_holidays{ 2012,  1,  2 } =
+	"Substitute Bank Holiday in lieu of 1 Jan";
 
 $_holidays{ 2004,  4,  9 } =
 $_holidays{ 2005,  3, 25 } =
@@ -74,7 +77,12 @@ $_holidays{ 2006,  4, 14 } =
 $_holidays{ 2007,  4,  6 } =
 $_holidays{ 2008,  3, 21 } =
 $_holidays{ 2009,  4, 10 } =
-$_holidays{ 2010,  4,  2 } = "Good Friday";
+$_holidays{ 2010,  4,  2 } = 
+$_holidays{ 2011,  4, 22 } = 
+$_holidays{ 2012,  4,  6 } = 
+$_holidays{ 2013,  3, 29 } = 
+$_holidays{ 2014,  4, 15 } = 
+	"Good Friday";
 
 $_holidays{ 2004,  4, 12 } =
 $_holidays{ 2005,  3, 28 } =
@@ -82,7 +90,12 @@ $_holidays{ 2006,  4, 17 } =
 $_holidays{ 2007,  4,  9 } =
 $_holidays{ 2008,  3, 24 } =
 $_holidays{ 2009,  4, 13 } =
-$_holidays{ 2010,  4,  5 } = "Easter Monday";
+$_holidays{ 2010,  4,  5 } = 
+$_holidays{ 2011,  4, 25 } = 
+$_holidays{ 2012,  4,  9 } = 
+$_holidays{ 2013,  4,  1 } = 
+$_holidays{ 2014,  4, 21 } = 
+	"Easter Monday";
 
 $_holidays{ 2004,  5,  3 } =
 $_holidays{ 2005,  5,  2 } =
@@ -90,7 +103,12 @@ $_holidays{ 2006,  5,  1 } =
 $_holidays{ 2007,  5,  7 } =
 $_holidays{ 2008,  5,  5 } =
 $_holidays{ 2009,  5,  4 } =
-$_holidays{ 2010,  5,  3 } = "Early May Bank Holiday";
+$_holidays{ 2010,  5,  3 } =
+$_holidays{ 2011,  5,  2 } = 
+$_holidays{ 2012,  5,  7 } = 
+$_holidays{ 2013,  5,  6 } = 
+$_holidays{ 2014,  5,  5 } = 
+	"Early May Bank Holiday";
 
 $_holidays{ 2004,  5, 31 } =
 $_holidays{ 2005,  5, 30 } =
@@ -98,7 +116,12 @@ $_holidays{ 2006,  5, 29 } =
 $_holidays{ 2007,  5, 28 } =
 $_holidays{ 2008,  5, 26 } =
 $_holidays{ 2009,  5, 25 } =
-$_holidays{ 2010,  5, 31 } = "Spring Bank Holiday";
+$_holidays{ 2010,  5, 31 } = 
+$_holidays{ 2011,  5, 30 } = 
+$_holidays{ 2012,  5, 28 } = 
+$_holidays{ 2013,  5, 27 } = 
+$_holidays{ 2014,  5, 26 } = 
+	"Spring Bank Holiday";
 
 $_holidays{ 2004,  8, 30 } =
 $_holidays{ 2005,  8, 29 } =
@@ -106,16 +129,24 @@ $_holidays{ 2006,  8, 28 } =
 $_holidays{ 2007,  8, 27 } =
 $_holidays{ 2008,  8, 25 } =
 $_holidays{ 2009,  8, 31 } =
-$_holidays{ 2010,  8, 30 } = "Summer Bank Holiday";
-
-$_holidays{ 2004, 12, 27 } = "Substitute Bank Holiday in lieu of 26 Dec";
+$_holidays{ 2010,  8, 30 } =
+$_holidays{ 2011,  8, 29 } =
+$_holidays{ 2012,  8, 27 } =
+$_holidays{ 2013,  8, 26 } =
+$_holidays{ 2014,  8, 25 } =
+	"Summer Bank Holiday";
 
 $_holidays{ 2004, 12, 28 } =
-$_holidays{ 2005, 12, 27 } = "Substitute Bank Holiday in lieu of 25 Dec";
+$_holidays{ 2005, 12, 27 } =
+$_holidays{ 2010, 12, 27 } =
+$_holidays{ 2011, 12, 27 } =
+	"Substitute Bank Holiday in lieu of 25 Dec";
 
-$_holidays{ 2010, 12, 27 } = "Substitute Bank Holiday in lieu of 25 Dec";
+$_holidays{ 2004, 12, 27 } =
+$_holidays{ 2009, 12, 28 } =
 $_holidays{ 2010, 12, 28 } = "Substitute Bank Holiday in lieu of 26 Dec";
 
+
 tie %holidays, 'Date::Holidays::UK::EnglandAndWales';
 
 sub is_uk_holiday {
@@ -149,7 +180,7 @@ sub FETCH {
 
 __END__
 
-=head1 Holiday Data
+=head1 SOURCE
 
 The DTI's webpage L<http://www.dti.gov.uk/employment/bank-public-holidays/index.html|http://www.dti.gov.uk/employment/bank-public-holidays/index.html>
 is taken as the canonical source for bank holidays.
@@ -157,7 +188,7 @@ is taken as the canonical source for bank holidays.
 =head1 CAVEATS
 
 We only currently contain the DTI Bank Holiday detail, which at the
-time of writing only covers the years 2004-2010.
+time of writing only covers the years 2004-2014.
 
 These Bank and Public Holidays are holidays in England and Wales,
 and not necessarily in Scotland and Northern Ireland.
@@ -170,7 +201,8 @@ Simply an update of work by Richard Clamp <richardc@fotango.com>, Amelie Guyot,
 
 =head1 COPYRIGHT
 
-Copyright 2004 Fotango.  All Rights Reserved.
+Copyright (C) 2004 Fotango.  All Rights Reserved.
+Copyright (C) 2007, 2011 Lee Goddard.  All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
@@ -179,7 +211,7 @@ it under the same terms as Perl itself.
 
 None known.
 
-Bugs should be reported to me via the CPAN RT system.
+Bugs should be reported via the CPAN RT system.
 L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Date::Holidays::UK::EnglandAndWales>.
 
 =head1 SEE ALSO
